@@ -27,8 +27,9 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "class_loader/multi_library_class_loader.h"
+#include "class_loader/multi_library_class_loader.hpp"
 
+#include <cstddef>
 #include <string>
 #include <vector>
 
@@ -48,11 +49,10 @@ MultiLibraryClassLoader::~MultiLibraryClassLoader()
 std::vector<std::string> MultiLibraryClassLoader::getRegisteredLibraries()
 {
   std::vector<std::string> libraries;
-  for (
-    LibraryToClassLoaderMap::iterator itr = active_class_loaders_.begin();
-    itr != active_class_loaders_.end(); itr++)
-  {
-    libraries.push_back(itr->first);
+  for (auto & it : active_class_loaders_) {
+    if (it.second != nullptr) {
+      libraries.push_back(it.first);
+    }
   }
   return libraries;
 }
@@ -62,24 +62,21 @@ ClassLoader * MultiLibraryClassLoader::getClassLoaderForLibrary(const std::strin
   LibraryToClassLoaderMap::iterator itr = active_class_loaders_.find(library_path);
   if (itr != active_class_loaders_.end()) {
     return itr->second;
-  } else {return NULL;}
+  } else {return nullptr;}
 }
 
 ClassLoaderVector MultiLibraryClassLoader::getAllAvailableClassLoaders()
 {
   ClassLoaderVector loaders;
-  for (
-    LibraryToClassLoaderMap::iterator itr = active_class_loaders_.begin();
-    itr != active_class_loaders_.end(); itr++)
-  {
-    loaders.push_back(itr->second);
+  for (auto & it : active_class_loaders_) {
+    loaders.push_back(it.second);
   }
   return loaders;
 }
 
 bool MultiLibraryClassLoader::isLibraryAvailable(const std::string & library_name)
 {
-  return getClassLoaderForLibrary(library_name) != NULL;
+  return getClassLoaderForLibrary(library_name) != nullptr;
 }
 
 void MultiLibraryClassLoader::loadLibrary(const std::string & library_path)
@@ -93,8 +90,9 @@ void MultiLibraryClassLoader::loadLibrary(const std::string & library_path)
 void MultiLibraryClassLoader::shutdownAllClassLoaders()
 {
   std::vector<std::string> available_libraries = getRegisteredLibraries();
-  for (unsigned int c = 0; c < available_libraries.size(); c++) {
-    unloadLibrary(available_libraries.at(c));
+
+  for (auto & library_path : getRegisteredLibraries()) {
+    unloadLibrary(library_path);
   }
 }
 
